pub fn route_wires(layout: &mut Layout, graph: &LayoutGraph)Expand description
Route all wires in the layout based on the graph connectivity.
pub fn route_wires(layout: &mut Layout, graph: &LayoutGraph)Route all wires in the layout based on the graph connectivity.