symbol_paths

Function symbol_paths 

pub fn symbol_paths(sym: SymbolType) -> Vec<PathCmd>
Get the path commands for a given symbol type.

All symbols are drawn in a normalized coordinate space centered at (0, 0) with a nominal size of ~30×30 units. The renderer scales and translates as needed.